# -*- coding: utf-8 -*-
"""
    Instagramy
    ~~~~~~~~~~

    A python package for Instagram. It scarpe the Instagram
    contents.

    :license: MIT License
"""

from .InstagramUser import InstagramUser
from .InstagramPost import InstagramPost
from .InstagramHashTag import InstagramHashTag
